@@ -132,10 +132,10 @@ analyse.variance <- function(dl, adjust.cell.sizes) {
 #'   \itemize{
 #'     \item 'exact': The model without a low rank approximation
 #'       that does not estimate the cell sizes.
-#'     \item 'exact-sizes': The model without a low rank approximation
+#'     \item 'exactsizes': The model without a low rank approximation
 #'       that does estimate the cell sizes.
 #'     \item 'lowrank': Low rank approximation to the 'exact' model.
-#'     \item 'lowrank-sizes': Low rank approximation to the 'exact-sizes' model.
+#'     \item 'lowranksizes': Low rank approximation to the 'exactsizes' model.
 #'   }
 #' @param adjust.cell.sizes Adjust by the cell sizes for better estimates of the hyperparameters
 #'
@@ -161,12 +161,13 @@ estimate.hyper <- function(
   dl <- within(dl, {
     #
     # Remember options that depend on the model
-    opts$model.name <- model.name
+    # Remove hyphens to keep backwards compatibility with old names
+    opts$model.name <- sub('-', '', model.name)
     opts$model.estimates.cell.sizes <- switch(
         opts$model.name,
-        "exact-sizes" = TRUE,
+        "exactsizes" = TRUE,
         "exact" = FALSE,
-        "lowrank-sizes" = TRUE,
+        "lowranksizes" = TRUE,
         "lowrank" = FALSE,
         stop('Unknown model name'))
     #
@@ -205,7 +206,7 @@ estimate.hyper <- function(
 #' @param dl de.lorean object
 #' @param number Number to sample if filter function or genes not supplied.
 #' @param genes The genes to keep.
-#' @param .filter Function that gakes a list of genes as input and returns
+#' @param .filter Function that takes a list of genes as input and returns
 #'     a vector of TRUE/FALSE
 #'
 #' @examples
@@ -232,7 +233,7 @@ filter_genes <- function(dl,
 #' @param dl de.lorean object
 #' @param number Number to sample if filter function or cells not supplied.
 #' @param cells The cells to keep.
-#' @param .filter Function that gakes a list of cells as input and returns
+#' @param .filter Function that takes a list of cells as input and returns
 #'     a vector of TRUE/FALSE
 #'
 #' @examples
@@ -421,47 +422,19 @@ within(dl, {
   )
 })
 
-#' Compile the model and cache the DSO to avoid unnecessary recompilation.
+
+#' Get the Stan model for a DeLorean object.
 #'
 #' @param dl de.lorean object
 #'
 #' @export
 #'
-compile.model <- function(dl) {
-  stan.model.file <- system.file(file.path('Stan',
-                                            sprintf('%s.stan',
-                                                    dl$opts$model.name)),
-                                  package='DeLorean',
-                                  mustWork=TRUE)
-  data.dir <- system.file('extdata', package='DeLorean')
-  compiled.model.file <-
-    file.path(tempdir(),
-              sprintf("DeLorean-%s.rds", dl$opts$model.name))
-  within(dl, {
-    if (file.exists(compiled.model.file)
-        &&
-        file.info(compiled.model.file)$mtime
-            > file.info(stan.model.file)$mtime)
-    {
-      message("Loading pre-compiled model from ", compiled.model.file)
-      compiled <- readRDS(compiled.model.file)
-    } else {
-      message("Compiling model")
-      compiled <- rstan::stan(file=stan.model.file, chains=0,
-                              data=stan.data)
-      message("Saving compiled model to ", compiled.model.file)
-      saveRDS(compiled, compiled.model.file)
-    }
-    # Try one iteration to check everything is OK
-    # message("Trying iteration")
-    fit <- rstan::stan(
-      fit=compiled,
-      data=stan.data,
-      init=make.chain.init.fn(dl),
-      warmup=1,
-      iter=1,
-      chains=1)
-  })
+get_model <- function(dl) {
+  model <- stanmodels[[dl$opts$model.name]]
+  if (is.null(model)) {
+    stop('Unknown model: ', model_name)
+  }
+  model
 }
 
 
@@ -863,12 +836,13 @@ within(dl, {
 })
 
 
-#' Perform all the steps necessary to fit the model.
-#' - prepare the data
-#' - compile the model
-#' - find suitable initialisations
-#' - fit the model using the specified method (sampling or variational Bayes)
-#' - process the posterior.
+#' Perform all the steps necessary to fit the model:
+#' \enumerate{
+#'   \item prepare the data
+#'   \item find suitable initialisations
+#'   \item fit the model using the specified method (sampling or variational Bayes)
+#'   \item process the posterior
+#' }
 #'
 #' @param dl de.lorean object
 #' @param method Fitting method:
@@ -888,7 +862,6 @@ fit.dl <- function(
     ...)
 {
   dl <- prepare.for.stan(dl)
-  dl <- compile.model(dl)
   dl <- find.good.ordering(dl, seriation.find.orderings)
   dl <- pseudotimes.from.orderings(dl)
   dl <- fit.model(dl, method=method, ...)
@@ -949,7 +922,7 @@ fit.model.sample <- function(
     mc.cores=num.cores,
     function(i)
       rstan::stan(
-        fit=dl$fit,
+        fit=get_model(dl),
         data=dl$stan.data,
         thin=thin,
         init=init.chain.good.tau,
@@ -959,7 +932,6 @@ fit.model.sample <- function(
         refresh=-1,
         ...))
   dl$fit <- rstan::sflist2stanfit(sflist)
-  dl$compiled <- NULL  # Delete large unneeded object
   return(dl)
 }
 
@@ -1032,7 +1004,7 @@ fit.model.vb <- function(
       # mc.cores=1,
       function(i) within(list(), {
         fit <- rstan::vb(
-          rstan::get_stanmodel(dl$fit),
+          get_model(dl),
           data=dl$stan.data,
           seed=i,
           init=init.chain.good.tau(i),
@@ -1067,7 +1039,7 @@ fit.model.vb <- function(
   } else {
     # Run single variational Bayes
     dl$fit <- rstan::vb(
-      rstan::get_stanmodel(dl$fit),
+      get_model(dl),
       data=dl$stan.data,
       seed=init.idx,
       init=init.chain.good.tau(init.idx),
@@ -1187,10 +1159,6 @@ process.posterior <- function(dl) {
     #
     # Get parameters from best iteration
     best.m <- lapply(samples.l, function(s) filter(s, iter == best.sample))
-    #
-    # Expose Stan functions from model
-    stan.fns <- new.env()
-    rstan::expose_stan_functions(fit, env = stan.fns)
   })
 }
 
@@ -1208,7 +1176,7 @@ optimise.sample <- function(
     ...)
 {
     with(dl, {
-        optimised <- rstan::optimizing(dl$fit@stanmodel,
+        optimised <- rstan::optimizing(dl$stanmodel,
                                 data=dl$stan.data,
                                 init=parameters,
                                 as_vector=FALSE,
